;; Generated package description from phps-mode.el  -*- no-byte-compile: t -*-
(define-package "phps-mode" "0.4.52.0.20260109.100035" "Major mode for PHP with code intelligence" '((emacs "26")) :commit "4d9df2563e37649fecdd76333ee793864a5739a3" :authors '(("Christian Johansson" . "christian@cvj.se")) :maintainer '("Christian Johansson" . "christian@cvj.se") :keywords '("tools" "convenience") :url "https://github.com/cjohansson/emacs-phps-mode")
